/*
 * This file is part of Invenio.
 * Copyright (C) 2016-2018 CERN.
 *
 * Invenio is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

$footer-background-color1: #8a8a8a;

#footer {
  color: darken($footer-background-color1, 40%);
}
