{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- if breadcrumbs|length > 1 %}
  <div class="ui breadcrumbs container">
    <div class="ui breadcrumb" itemprop="breadcrumb">
      {%- for breadcrumb in breadcrumbs %}
        {%- if loop.last %}
          <div class="active section">
            {{ breadcrumb.text|safe }}
          </div>
        {%- else %}
          <a href="{{ breadcrumb.url }}" class="section">
            {{ breadcrumb.text|safe }}
          </a>
          <i class="right angle icon divider"></i>
        {%- endif %}
      {%- endfor %}
    </div>
  </div>
{%- endif %}
